==> open-vulnerability-clients-7.3.2-sources.jar: io/github/jeremylong/openvulnerability/client/nvd/Node.java <==
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 * Copyright (c) 2023-2025 Jeremy Long. All Rights Reserved.
 */
package io.github.jeremylong.openvulnerability.client.nvd;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonValue;
import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
import org.jspecify.annotations.NullMarked;
import org.jspecify.annotations.Nullable;

import java.io.Serializable;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * Defines a configuration node in an NVD applicability statement.
 */
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
@JsonPropertyOrder({"operator", "negate", "cpeMatch"})
@NullMarked
public class Node implements Serializable {

    /**
     * Serialization version UID.
     */
    private static final long serialVersionUID = 3573822908057141798L;
    /**
     * (Required)
     */
    @JsonProperty("operator")
    private Operator operator;
    @JsonProperty("negate")
    private @Nullable Boolean negate;
    /**
     * (Required)
     */
    @JsonProperty("cpeMatch")
    private List<CpeMatch> cpeMatch;

    @SuppressFBWarnings(value = {"EI_EXPOSE_REP",
            "EI_EXPOSE_REP2"}, justification = "I prefer to suppress these FindBugs warnings")
    @JsonCreator
    public Node(@JsonProperty("operator") Operator operator, @JsonProperty("cpeMatch") List<CpeMatch> cpeMatch) {
        this.operator = operator;
        this.cpeMatch = cpeMatch;
    }

    @SuppressFBWarnings(value = {"EI_EXPOSE_REP",
            "EI_EXPOSE_REP2"}, justification = "I prefer to suppress these FindBugs warnings")
    public Node(Operator operator, @Nullable Boolean negate, List<CpeMatch> cpeMatch) {
        this(operator, cpeMatch);
        this.negate = negate;
    }

    /**
     * (Required)
     *
     * @return operator
     */
    @JsonProperty("operator")
    public Operator getOperator() {
        return operator;
    }

    /**
     * @return negate
     */
    @JsonProperty("negate")
    public @Nullable Boolean getNegate() {
        return negate;
    }

    /**
     * (Required)
     *
     * @return cpeMatch
     */
    @JsonProperty("cpeMatch")
    @SuppressFBWarnings(value = {"EI_EXPOSE_REP",
            "EI_EXPOSE_REP2"}, justification = "I prefer to suppress these FindBugs warnings")
    public List<CpeMatch> getCpeMatch() {
        return cpeMatch;
    }

    @Override
    public String toString() {
        return "Node{" + "operator=" + operator + ", negate=" + negate + ", cpeMatch=" + cpeMatch + '}';
    }

    @Override
    public boolean equals(Object o) {
        if (this == o)
            return true;
        if (o == null || getClass() != o.getClass())
            return false;
        Node node = (Node) o;
        return operator == node.operator && Objects.equals(negate, node.negate)
                && Objects.equals(cpeMatch, node.cpeMatch);
    }

    @Override
    public int hashCode() {
        return Objects.hash(operator, negate, cpeMatch);
    }

    public enum Operator {

        AND("AND"), OR("OR");

        private final static Map<String, Operator> CONSTANTS = new HashMap<>();

        static {
            for (Operator c : values()) {
                CONSTANTS.put(c.value, c);
            }
        }

        private final String value;

        Operator(String value) {
            this.value = value;
        }

        @JsonCreator
        public static Operator fromValue(String value) {
            Operator constant = CONSTANTS.get(value);
            if (constant == null) {
                throw new IllegalArgumentException(value);
            } else {
                return constant;
            }
        }

        @Override
        public String toString() {
            return this.value;
        }

        @JsonValue
        public String value() {
            return this.value;
        }

    }

}

==> open-vulnerability-clients-9.0.2-sources.jar: io/github/jeremylong/openvulnerability/client/nvd/Node.java <==
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 * Copyright (c) 2023-2025 Jeremy Long. All Rights Reserved.
 */
package io.github.jeremylong.openvulnerability.client.nvd;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonValue;
import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
import org.jspecify.annotations.NullMarked;
import org.jspecify.annotations.Nullable;

import java.io.Serializable;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * Defines a configuration node in an NVD applicability statement.
 */
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
@JsonPropertyOrder({"operator", "negate", "cpeMatch"})
@NullMarked
public class Node implements Serializable {

    /**
     * Serialization version UID.
     */
    private static final long serialVersionUID = 3573822908057141798L;
    /**
     * (Required)
     */
    @JsonProperty("operator")
    private Operator operator;
    @JsonProperty("negate")
    private @Nullable Boolean negate;
    /**
     * (Required)
     */
    @JsonProperty("cpeMatch")
    private List<CpeMatch> cpeMatch;

    /**
     * Constructs a new Node with the specified operator and CPE matches.
     *
     * @param operator the logical operator
     * @param cpeMatch the list of CPE matches
     */
    @SuppressFBWarnings(value = {"EI_EXPOSE_REP"}, justification = "I prefer to suppress these FindBugs warnings")
    @JsonCreator
    public Node(@JsonProperty("operator") Operator operator, @JsonProperty("cpeMatch") List<CpeMatch> cpeMatch) {
        this.operator = operator;
        this.cpeMatch = cpeMatch;
    }

    /**
     * Constructs a new Node with the specified operator, negate flag, and CPE matches.
     *
     * @param operator the logical operator
     * @param negate whether to negate the result
     * @param cpeMatch the list of CPE matches
     */
    public Node(Operator operator, @Nullable Boolean negate, List<CpeMatch> cpeMatch) {
        this(operator, cpeMatch);
        this.negate = negate;
    }

    /**
     * (Required)
     *
     * @return operator
     */
    @JsonProperty("operator")
    public Operator getOperator() {
        return operator;
    }

    /**
     * @return negate
     */
    @JsonProperty("negate")
    public @Nullable Boolean getNegate() {
        return negate;
    }

    /**
     * (Required)
     *
     * @return cpeMatch
     */
    @JsonProperty("cpeMatch")
    @SuppressFBWarnings(value = {"EI_EXPOSE_REP"}, justification = "I prefer to suppress these FindBugs warnings")
    public List<CpeMatch> getCpeMatch() {
        return cpeMatch;
    }

    @Override
    public String toString() {
        return "Node{" + "operator=" + operator + ", negate=" + negate + ", cpeMatch=" + cpeMatch + '}';
    }

    @Override
    public boolean equals(Object o) {
        if (this == o)
            return true;
        if (o == null || getClass() != o.getClass())
            return false;
        Node node = (Node) o;
        return operator == node.operator && Objects.equals(negate, node.negate)
                && Objects.equals(cpeMatch, node.cpeMatch);
    }

    @Override
    public int hashCode() {
        return Objects.hash(operator, negate, cpeMatch);
    }

    /**
     * Logical operators for combining CPE matches.
     */
    public enum Operator {

        /** Logical AND operator. */
        AND("AND"),
        /** Logical OR operator. */
        OR("OR");

        private final static Map<String, Operator> CONSTANTS = new HashMap<>();

        static {
            for (Operator c : values()) {
                CONSTANTS.put(c.value, c);
            }
        }

        private final String value;

        Operator(String value) {
            this.value = value;
        }

        /**
         * Returns the enum constant for the given value.
         *
         * @param value the value
         * @return the operator
         * @throws IllegalArgumentException if no constant exists for the value
         */
        @JsonCreator
        public static Operator fromValue(String value) {
            Operator constant = CONSTANTS.get(value);
            if (constant == null) {
                throw new IllegalArgumentException(value);
            } else {
                return constant;
            }
        }

        @Override
        public String toString() {
            return this.value;
        }

        /**
         * Returns the value of this operator.
         *
         * @return the value
         */
        @JsonValue
        public String value() {
            return this.value;
        }

    }

}
